==> rivet-3.1.11.tar.gz: Rivet-3.1.11/analyses/pluginPetra/TASSO_1986_I228876.cc <==
// -*- C++ -*-
#include "Rivet/Analysis.hh"
#include "Rivet/Projections/FinalState.hh"

namespace Rivet {


  /// @brief gamma gamma -> pi+pi-pi0
  class TASSO_1986_I228876 : public Analysis {
  public:

    /// Constructor
    RIVET_DEFAULT_ANALYSIS_CTOR(TASSO_1986_I228876);


    /// @name Analysis methods
    /// @{

    /// Book histograms and initialise projections before the run
    void init() {
      // Initialise and register projections
      declare(FinalState(), "FS");
      // book histos
      if(inRange(sqrtS()/GeV,0.9,2.4)) {
	book(_nMeson,"TMP/nMeso");
      }
      else
	throw Error("Invalid CMS energy for TASSO_1986_I228876");
    }

    /// Perform the per-event analysis
    void analyze(const Event& event) {
      const FinalState& fs = apply<FinalState>(event, "FS");
      // find the final-state particles
      map<long,int> nCount;
      int ntotal(0);
      for (const Particle& p : fs.particles()) {
	nCount[p.pid()] += 1;
	++ntotal;
      }
      // check the 3 meson final state
      if(ntotal==3 && nCount[PID::PI0]==1 &&
	 nCount[PID::PIPLUS]==1 && nCount[PID::PIMINUS]==1 ) {
	_nMeson->fill();
      }
    }


    /// Normalise histograms etc., after the run
    void finalize() {
      double fact = crossSection()/nanobarn/sumOfWeights();
      double sigma = _nMeson->val()*fact;
      double error = _nMeson->err()*fact;
      Scatter2D temphisto(refData(1, 1, 1));
      Scatter2DPtr mult;
      book(mult, 1, 1, 1);
      for (size_t b = 0; b < temphisto.numPoints(); b++) {
	const double x  = temphisto.point(b).x();
	pair<double,double> ex = temphisto.point(b).xErrs();
	pair<double,double> ex2 = ex;
	if(ex2.first ==0.) ex2. first=0.0001;
	if(ex2.second==0.) ex2.second=0.0001;
	if (inRange(sqrtS()/GeV, x-ex2.first, x+ex2.second)) {
	  mult->addPoint(x, sigma, ex, make_pair(error,error));
	}
	else {
	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
	}
      }
    }

    /// @}


    /// @name Histograms
    /// @{
    CounterPtr _nMeson;
    /// @}


  };


  RIVET_DECLARE_PLUGIN(TASSO_1986_I228876);

}

==> rivet-4.0.2.tar.gz: Rivet-4.0.2/analyses/pluginPetra/TASSO_1986_I228876.cc <==
// -*- C++ -*-
#include "Rivet/Analysis.hh"
#include "Rivet/Projections/FinalState.hh"

namespace Rivet {


  /// @brief gamma gamma -> pi+pi-pi0
  class TASSO_1986_I228876 : public Analysis {
  public:

    /// Constructor
    RIVET_DEFAULT_ANALYSIS_CTOR(TASSO_1986_I228876);


    /// @name Analysis methods
    /// @{

    /// Book histograms and initialise projections before the run
    void init() {
      // Initialise and register projections
      declare(FinalState(), "FS");
      // book histos
      if (inRange(sqrtS()/GeV,0.9,2.4)) {
        book(_nMeson, "TMP/nMeson", refData(1, 1, 1));
      }
      else {
        throw Error("Invalid CMS energy for TASSO_1986_I228876");
      }
    }

    /// Perform the per-event analysis
    void analyze(const Event& event) {
      const FinalState& fs = apply<FinalState>(event, "FS");
      // find the final-state particles
      map<long,int> nCount;
      int ntotal(0);
      for (const Particle& p : fs.particles()) {
        nCount[p.pid()] += 1;
        ++ntotal;
      }
      // check the 3 meson final state
      if (ntotal==3 && nCount[PID::PI0]==1 &&
          nCount[PID::PIPLUS]==1 && nCount[PID::PIMINUS]==1 ) {
        _nMeson->fill(sqrtS()/GeV);
      }
    }


    /// Normalise histograms etc., after the run
    void finalize() {
      scale(_nMeson, crossSection()/nanobarn/sumOfWeights());
      Estimate1DPtr tmp;
      book(tmp,1,1,1);
      barchart(_nMeson,tmp);
    }

    /// @}


    /// @name Histograms
    /// @{
    Histo1DPtr _nMeson;
    /// @}


  };


  RIVET_DECLARE_PLUGIN(TASSO_1986_I228876);

}
